pub struct DialogCloseCanceledArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for DIALOG_CLOSE_CANCELED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathDialog widget.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl DialogCloseCanceledArgs
impl DialogCloseCanceledArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(target: impl Into<WidgetPath>) -> Self
pub fn now(target: impl Into<WidgetPath>) -> Self
Arguments for event that happened now (INSTANT.now).