pub struct NativeDialogCapacity(/* private fields */);Expand description
Dialog operations the view-process implements.
Implementations
Sourceimpl DialogCapability
impl DialogCapability
Sourcepub const MESSAGE: DialogCapability
pub const MESSAGE: DialogCapability
View-process can show message dialogs.
Sourcepub const OPEN_FILE: DialogCapability
pub const OPEN_FILE: DialogCapability
View-process can show single file picker.
Sourcepub const OPEN_FILES: DialogCapability
pub const OPEN_FILES: DialogCapability
View-process can show multi file picker.
Sourcepub const SAVE_FILE: DialogCapability
pub const SAVE_FILE: DialogCapability
View-process can show save single file picker.
Sourcepub const SELECT_FOLDER: DialogCapability
pub const SELECT_FOLDER: DialogCapability
View-process can show single directory picker.
Sourcepub const SELECT_FOLDERS: DialogCapability
pub const SELECT_FOLDERS: DialogCapability
View-process can show multi directory picker.
Sourcepub const NOTIFICATION: DialogCapability
pub const NOTIFICATION: DialogCapability
View-process can insert notifications in the system list.
Sourcepub const NOTIFICATION_ACTIONS: DialogCapability
pub const NOTIFICATION_ACTIONS: DialogCapability
View-process can show custom actions for dismissing the notification.
Sourcepub const CLOSE_NOTIFICATION: DialogCapability
pub const CLOSE_NOTIFICATION: DialogCapability
View-process can handle the special close notification update that removes the notification.
Sourcepub const UPDATE_NOTIFICATION: DialogCapability
pub const UPDATE_NOTIFICATION: DialogCapability
View-process can update notification content.
Sourceimpl DialogCapability
impl DialogCapability
Sourcepub const fn empty() -> DialogCapability
pub const fn empty() -> DialogCapability
Get a flags value with all bits unset.
Sourcepub const fn all() -> DialogCapability
pub const fn all() -> DialogCapability
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<DialogCapability>
pub const fn from_bits(bits: u32) -> Option<DialogCapability>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> DialogCapability
pub const fn from_bits_truncate(bits: u32) -> DialogCapability
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> DialogCapability
pub const fn from_bits_retain(bits: u32) -> DialogCapability
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DialogCapability>
pub fn from_name(name: &str) -> Option<DialogCapability>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DialogCapability) -> bool
pub const fn intersects(&self, other: DialogCapability) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: DialogCapability) -> bool
pub const fn contains(&self, other: DialogCapability) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: DialogCapability)
pub fn insert(&mut self, other: DialogCapability)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: DialogCapability)
pub fn remove(&mut self, other: DialogCapability)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DialogCapability)
pub fn toggle(&mut self, other: DialogCapability)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: DialogCapability, value: bool)
pub fn set(&mut self, other: DialogCapability, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: DialogCapability) -> DialogCapability
pub const fn intersection(self, other: DialogCapability) -> DialogCapability
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: DialogCapability) -> DialogCapability
pub const fn union(self, other: DialogCapability) -> DialogCapability
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: DialogCapability) -> DialogCapability
pub const fn difference(self, other: DialogCapability) -> DialogCapability
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DialogCapability,
) -> DialogCapability
pub const fn symmetric_difference( self, other: DialogCapability, ) -> DialogCapability
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> DialogCapability
pub const fn complement(self) -> DialogCapability
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DialogCapability
impl DialogCapability
Sourcepub const fn iter(&self) -> Iter<DialogCapability>
pub const fn iter(&self) -> Iter<DialogCapability>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DialogCapability>
pub const fn iter_names(&self) -> IterNames<DialogCapability>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.