on_dialog_close_canceled

Function on_dialog_close_canceled 

pub fn on_dialog_close_canceled(
    child: impl IntoUiNode,
    handler: Handler<DialogCloseCanceledArgs>,
) -> UiNode
P Dialogs must only close using DIALOG.respond.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.