pub fn on_pre_dialog_close_canceled(
child: impl IntoUiNode,
handler: Handler<DialogCloseCanceledArgs>,
) -> UiNodeExpand description
P
Dialogs must only close using DIALOG.respond.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.